**    ModelEco : MODELisation en programmation mathmatique pour l'analyse ECOnomique de l'agriculure    **

*-----------------------------------------------------------------------------*
$Ontext
Nom              Elevage_viande.gms
Sequence         2 - Le modle d'exploitation agricole
Type             LP
Langage GAMS     Tableaux  3 dimensions. Equations indices
Description
Modle d'levage
$Offtext
*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~*


*----------                          INDICES                        ----------*
sets
C cultures  /orge,herbe,foin/
A animaux   /vache,veauF,veauM,taur1,taur2,genisse1,genisse2,genisse3/
;

*----------                          DONNEES                        ----------*
scalar
DTERRE   disponibilite de terre en hectares       /100/
DMO      disponibilite de travail en heures      /2000/
PROL     prolificite du troupeau                  /0.9/
SEXRATIO sex ratio                                /0.5/
RENOUV   taux de renouvellement                  /0.18/
REFORM   taux de reforme                         /0.18/
;

parameter
BMO(C) besoins en travail des cultures (heures par hectare)
/orge   20
 herbe   8
 foin   10/

PX(C) prix des cultures (euros par kg)
/orge  0.10/

RDT(C) rendement de culture (kg par hectare)
/orge  6000
 herbe 2000
 foin  3000/

CHO(C) charges operationnelles par culture (euros par hectare)
/orge  380
 herbe  50
 foin  100/

BTA(a)  besoin en temps de travaux en heures par animal
/vache   10
 veauF    4
 veauM    4
 taur1    6
 taur2    3
 genisse1 4
 genisse2 6
 genisse3 8/

PXA(A) prix de vente par animal (euros)
/vache    1000
 veauM     650
 veauF     695
 taur2     929
 genisse3 1200/
;

table BES(A,C) besoin par animal en  fourrages (KG par animal)
          orge      foin      herbe
 vache     661      1543       1187
 veauM     119       474        365
 veauF     119       474        365
 taur1    1044      1392
 taur2     204       818
 genisse1  143       570        438
 genisse2  204       818        629
 genisse3  234       934        718
;

*----------                         MODELE                          ----------*

variable Z revenu de l'agriculteur ;

positive variables
N(A)     nombre d'animaux par type
X(C)     surface par culture
V(C)     quantit de cereales vendues
AV(A)    animaux vendus
;

equations

OBJ              fonction objectif
TRAVAIL          contrainte de travail
TERRE            contrainte de surface
ALIMENT(C)    contrainte alimentaire
DEMO1            prolificit male
DEMO2            prolificit femelle
DEMO3            mme nombre de genisses 1re et 2ime anne
DEMO4            mme nombre de genisses 2ime et 3ime anne
DEMO5            mme nombre de taurillons anne 1 et 2
VENTE1           vente des vaches rformes
VENTE2           vente des taurillons 2ime anne
VENTE3           vente des genisses restantes
VENTE4           vente des veaux femelles
VENTE5           vente des veaux males

;

OBJ.. sum (A, AV(A)*PXA(A)) + sum(C, V(C)*PX(C)) - sum(C,X(C)*CHO(C)) =e= Z ;

TRAVAIL.. sum (A, BTA(A)*N(A))+ sum(C, BMO(C)*X(C) ) =l= DMO ;

TERRE.. sum(C, X(C)) =l= DTERRE ;

ALIMENT(C).. sum(A, BES(A,C)*N(A)) =l= RDT(C)*X(C)-V(c) ;

DEMO1.. N('veauM') + N('taur1') =e= prol * sexratio * N('vache');

DEMO2.. N('veauF') + N('genisse1') =e= prol * sexratio * N('vache');

DEMO3.. N('genisse1') =e= N('genisse2');

DEMO4.. N('genisse3') =e= N('genisse2') ;

DEMO5.. N('taur1') =e= N('taur2')   ;

VENTE1.. AV('vache') =e= renouv * N('vache')   ;

VENTE2.. AV('taur2') =e= N('taur2') ;

VENTE3.. AV('genisse3') =e= N('genisse3') - N('vache')*renouv ;

VENTE4.. AV('veauF') =e= N('veauF')  ;

VENTE5.. AV('veauM')  =e= N('veauM') ;


model elevage /all/;

*----------                        SOLUTION                         ----------*
solve elevage using LP maximizing Z ;


Display N.L, Z.l, X.l, V.l;
